package com.jjt.order.service;

import java.util.List;
import com.jjt.order.domain.TwinOrderDetail;

/**
 * 销售订单明细信息Service接口
 *
 * @author wukai
 * @date 2025-01-16
 */
public interface ITwinOrderDetailService {
    /**
     * 查询销售订单明细信息
     *
     * @param odId 销售订单明细信息主键
     * @return 销售订单明细信息
     */
    public TwinOrderDetail selectTwinOrderDetailByOdId(Long odId);

    /**
     * 查询销售订单明细信息列表
     *
     * @param twinOrderDetail 销售订单明细信息
     * @return 销售订单明细信息集合
     */
    public List<TwinOrderDetail> selectTwinOrderDetailList(TwinOrderDetail twinOrderDetail);

    /**
     * 新增销售订单明细信息
     *
     * @param twinOrderDetail 销售订单明细信息
     * @return 结果
     */
    public int insertTwinOrderDetail(TwinOrderDetail twinOrderDetail);

    /**
     * 修改销售订单明细信息
     *
     * @param twinOrderDetail 销售订单明细信息
     * @return 结果
     */
    public int updateTwinOrderDetail(TwinOrderDetail twinOrderDetail);

    /**
     * 批量删除销售订单明细信息
     *
     * @param odIds 需要删除的销售订单明细信息主键集合
     * @return 结果
     */
    public int deleteTwinOrderDetailByOdIds(Long[] odIds);

    /**
     * 删除销售订单明细信息信息
     *
     * @param odId 销售订单明细信息主键
     * @return 结果
     */
    public int deleteTwinOrderDetailByOdId(Long odId);
}
